# Keyboard mate

A drop-dead simple keyboard monitor for nums, caps.

## Installation

```
pip install keyboard-mate
```

## Usage

If you want to monitor nums lock, run:

```
kbm-nums
```

If you want to monitor caps lock, run:

```
kbm-caps
```